@@ -2,7 +2,7 @@ package Dist::Zilla::Plugin::ReversionOnRelease;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use version;
 use Version::Next;
@@ -22,7 +22,11 @@ qr/ ( (?i: Revision: \s+ ) | v | )
     ( (?: _ \d+ )? ) /x;
 # from perl-reversion
 my $VersionRegexp =
-  qr{ ^ ( .*?  [\$\*] (?: \w+ (?: :: | ' ) )* VERSION \s* = \D*? )
+  qr{ ^ (
+            .*?  [\$\*] (?: \w+ (?: :: | ' ) )* VERSION \s* = \D*?
+            |
+            \s* package \s+ [\w\:\']+ \s+
+        )
             ( (?i: Revision: \s+ ) | v | )
             ( \d+ (?: [.] \d+)* )
             ( (?: _ \d+ )? )
@@ -171,7 +175,7 @@ Unlike C<perl-reversion>, this module uses L<Version::Next> to get
 more naturally incremented version, instead of a little strict 3-digit
 rules in L<Perl::Version>.
 
-You B<should not> this plugin with any code munging or Pod::Weaver
+You B<should not> use this plugin with any code munging or Pod::Weaver
 plugins.
 
 By default, this plugin bumps version by the smallest possible
@@ -197,6 +201,22 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Dist::Milla> L<Version::Next> L<Dist::Zilla::Plugin::BumpVersion>
+=over 4
+
+=item * L<Dist::Milla>
+
+=item * L<Version::Next>
+
+=item * L<Dist::Zilla::Plugin::BumpVersion>
+
+=item * L<Dist::Zilla::Plugin::RewriteVersion> - also takes $VERSION from the main module; ensures all $VERSIONs are consistent 
+
+=item * L<Dist::Zilla::Plugin::BumpVersionAfterRelease> - edits the $VERSION in the repository code to reflect the new version, after release
+
+=item * L<Dist::Zilla::Plugin::RewriteVersion::Transitional> - like L<Dist::Zilla::Plugin::RewriteVersion>, but munges the version in if it was not already present
+
+=item * L<Dist::Zilla::Plugin::BumpVersionAfterRelease::Transitional> - like L<Dist::Zilla::Plugin::BumpVersionAfterRelease>, but also adds the $VERSION into the repository code if it was not already present
+
+=back
 
 =cut
